@@ -12,11 +12,8 @@ def parse_args():
     parser.add_argument('--lang', type=str,help="Browser language code (tr,en,es,..)", default="")
     parser.add_argument('--chromedriver', type=str, help="Custom chromedriver path", default="")
     parser.add_argument('-o', '--output', type=str, help="Output file name", default="")
-    parser.add_argument('--fake-name', type=str, help="Fake account name", default="")
-    parser.add_argument('--fake-username', type=str, help="Fake account username", default="")
-    parser.add_argument('--fake-content', type=str, help="Fake tweet content", default=None)
-    parser.add_argument('--fake-verified', type=bool, help="Fake tweet verified status", default=None)
-    parser.add_argument('--fake-image', type=str, help="Fake account image (url or local file)", default="")
+    parser.add_argument('-sp', '--show-parent-tweets', dest='show_parent_tweets', action='store_true', help="Show parent tweets")
+    parser.set_defaults(show_parent_tweets=False)
 
     args = parser.parse_args()
     return args
@@ -24,12 +21,11 @@ def parse_args():
 
 def main():
     args = parse_args()
-    tweet = TweetCapture(args.mode, args.night_mode)
+    tweet = TweetCapture(args.mode, args.night_mode, show_parent_tweets=args.show_parent_tweets)
     tweet.set_lang(args.lang)
     tweet.set_wait_time(args.t)
     if len(args.chromedriver) > 0:
         tweet.set_chromedriver_path(args.chromedriver)
-    tweet.Fake.create(args.fake_name, args.fake_content, args.fake_username, args.fake_image, args.fake_verified)
     try:
         filename = run(tweet.screenshot(args.url, args.output))
         print(f"Screenshot is saved: {filename}")
